 /*------------------------------------------------------------------------
    File        : ShowPersistentObjects
    Description : Show objects that are persistent in the current session
    Author(s)   : usb13003
    Created     : Tue Apr 27 15:23:46 EDT 2010
    Notes       : 
  ----------------------------------------------------------------------*/

USING Progress.Lang.*.
USING Progress.Windows.Form.

ROUTINE-LEVEL ON ERROR UNDO, THROW.

CLASS ShowPersistentObjects INHERITS Form   : 
  
  DEFINE PRIVATE VARIABLE components AS System.ComponentModel.IContainer NO-UNDO.

  DEFINE PRIVATE VARIABLE ultraGrid1 AS Infragistics.Win.UltraWinGrid.UltraGrid NO-UNDO.
  
  DEFINE VARIABLE objProBindingSource AS CLASS Progress.Data.BindingSource NO-UNDO.

  DEFINE PRIVATE VARIABLE m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom AS Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea NO-UNDO.
  DEFINE PRIVATE VARIABLE m_ShowPersistentObjects_Toolbars_Dock_Area_Left AS Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea NO-UNDO.
  DEFINE PRIVATE VARIABLE m_ShowPersistentObjects_Toolbars_Dock_Area_Right AS Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea NO-UNDO.
  DEFINE PRIVATE VARIABLE m_ShowPersistentObjects_Toolbars_Dock_Area_Top AS Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea NO-UNDO.
  DEFINE PRIVATE VARIABLE ultraToolbarsManager1 AS Infragistics.Win.UltraWinToolbars.UltraToolbarsManager NO-UNDO.

  DEFINE PRIVATE VARIABLE ultraGridExcelExporter1 AS Infragistics.Win.UltraWinGrid.ExcelExport.UltraGridExcelExporter NO-UNDO.
  
  DEFINE TEMP-TABLE ttPermanentObject NO-UNDO
   FIELD ObjectType             AS CHARACTER
   FIELD ObjectName             AS CHARACTER
   FIELD ObjectID               AS CHARACTER
   FIELD InstantiatingProcedure AS CHARACTER
   INDEX ByObjectTypeNameID IS PRIMARY ObjectType ObjectName ObjectID
   .
   
  DEFINE QUERY qttPermanentObject FOR ttPermanentObject SCROLLING.

  CONSTRUCTOR PUBLIC ShowPersistentObjects ( ):
    SUPER().
    
    QUERY qttPermanentObject:QUERY-PREPARE("PRESELECT EACH ttPermanentObject":U).

    InitializeComponent().

    objProBindingSource = NEW Progress.Data.BindingSource(QUERY qttPermanentObject:HANDLE).
    THIS-OBJECT:FillPersistentObjects().
    objProBindingSource:AutoSync = FALSE.
    THIS-OBJECT:ultraGrid1:DataSource = objProBindingSource. /* must be after InitializeComponent */
    
    CATCH e AS Progress.Lang.Error:
      UNDO, THROW e.
    END CATCH.

  END CONSTRUCTOR.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

  METHOD PROTECTED VOID AddPersistentObjects( phObject AS HANDLE ):
    
    DO WHILE VALID-HANDLE(phObject):
      THIS-OBJECT:AddPersistentObject(
       phObject:TYPE,
       (IF phObject:NAME > "":U
        THEN phObject:NAME
        ELSE IF CAN-QUERY(phObject, "TITLE":U)
        THEN phObject:TITLE
        ELSE "?":U),
       STRING(phObject),
       IF VALID-HANDLE(phObject:INSTANTIATING-PROCEDURE) 
       THEN phObject:INSTANTIATING-PROCEDURE:FILE-NAME
       ELSE "?":U).
      phObject = phObject:NEXT-SIBLING.
    END. /* DO WHILE VALID-HANDLE(phObject) */

  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

  METHOD PROTECTED VOID AddPersistentObjects( pObject AS Progress.Lang.Object ):
    DEFINE VARIABLE objDotNet AS CLASS System.Object NO-UNDO.
    DEFINE VARIABLE objForm AS CLASS Progress.Windows.Form NO-UNDO.

    DO WHILE VALID-OBJECT(pObject):
      objDotNet = CAST(pObject, System.Object) NO-ERROR.

      IF VALID-OBJECT(objDotNet)
      THEN THIS-OBJECT:AddPersistentObject(
       objDotNet:GetType():FullName /* Type */,
       objDotNet:GetType():FullName /* Name */,
       STRING(INTEGER(pObject)) + "-" + STRING(pObject) /* ID */,
       "?":U /* Instantiator */).
      ELSE DO:
        objForm = CAST(pObject, Progress.Windows.Form) NO-ERROR.
        IF VALID-OBJECT(objForm)
        THEN THIS-OBJECT:AddPersistentObject(
              "Progress.Windows.Form":U /* Type */,
              pObject:GetClass():TypeName + "-" + objForm:Text /* Name */,
              STRING(INTEGER(pObject)) + "-" + STRING(pObject) /* ID */,
              "?":U /* Instantiator */).
        ELSE THIS-OBJECT:AddPersistentObject(
              pObject:GetClass():TypeName /* Type */,
              pObject:GetClass():TypeName /* Name */,
              STRING(INTEGER(pObject)) + "-" + STRING(pObject) /* ID */,
              "?":U /* Instantiator */).
      END. /* ... ELSE */
       
      pObject = pObject:Next-Sibling.
    END. /* DO WHILE VALID-HANDLE(phObject) */
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

  METHOD PROTECTED VOID AddPersistentObject(
   pcObjectType             AS CHARACTER,
   pcObjectName             AS CHARACTER,
   pcObjectID               AS CHARACTER,
   pcInstantiatingProcedure AS CHARACTER
   ):

    CREATE ttPermanentObject.
    ASSIGN
     ttPermanentObject.ObjectType = pcObjectType
     ttPermanentObject.ObjectName = pcObjectName
     ttPermanentObject.ObjectID = pcObjectID
     ttPermanentObject.InstantiatingProcedure = pcInstantiatingProcedure
    .
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

  METHOD PROTECTED VOID FillPersistentObjects(  ):
    SESSION:SET-WAIT-STATE("GENERAL":U).
    EMPTY TEMP-TABLE ttPermanentObject.
    System.GC:Collect().
    System.GC:WaitForPendingFinalizers().
    System.GC:Collect().
    AddPersistentObjects(SESSION:FIRST-ASYNC-REQUEST).
    AddPersistentObjects(SESSION:FIRST-BUFFER).
    AddPersistentObjects(SESSION:FIRST-CHILD).
    AddPersistentObjects(SESSION:FIRST-DATA-SOURCE).
    AddPersistentObjects(SESSION:FIRST-DATASET).
/*    AddPersistentObjects(SESSION:FIRST-FORM).*/ /* this will be covered by the following SESSION:FIRST-OBJECT */
    AddPersistentObjects(SESSION:FIRST-OBJECT).
    AddPersistentObjects(SESSION:FIRST-PROCEDURE).
    AddPersistentObjects(SESSION:FIRST-QUERY).
    AddPersistentObjects(SESSION:FIRST-SERVER).
    AddPersistentObjects(SESSION:FIRST-SERVER-SOCKET).
    AddPersistentObjects(SESSION:FIRST-SOCKET).
    QUERY qttPermanentObject:QUERY-OPEN().
    CAST(THIS-OBJECT:ultraToolbarsManager1:Tools:Item['Num Objects':U], Infragistics.Win.UltraWinToolbars.TextBoxTool):Text = STRING(QUERY qttPermanentObject:NUM-RESULTS).
    THIS-OBJECT:objProBindingSource:RefreshAll().
    SESSION:SET-WAIT-STATE("":U).
  END METHOD.

  METHOD PRIVATE VOID InitializeComponent(  ):
    
    /* NOTE: The following method is automatically generated.
    
    We strongly suggest that the contents of this method only be modified using the
    Visual Designer to avoid any incompatible modifications.
    
    Modifying the contents of this method using a code editor will invalidate any support for this file. */
    THIS-OBJECT:components = NEW System.ComponentModel.Container().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance1 AS Infragistics.Win.Appearance NO-UNDO.
    appearance1 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraGridBand1 AS Infragistics.Win.UltraWinGrid.UltraGridBand NO-UNDO.
    ultraGridBand1 = NEW Infragistics.Win.UltraWinGrid.UltraGridBand("Band 0", -1).
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraGridColumn1 AS Infragistics.Win.UltraWinGrid.UltraGridColumn NO-UNDO.
    ultraGridColumn1 = NEW Infragistics.Win.UltraWinGrid.UltraGridColumn("ObjectType").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraGridColumn2 AS Infragistics.Win.UltraWinGrid.UltraGridColumn NO-UNDO.
    ultraGridColumn2 = NEW Infragistics.Win.UltraWinGrid.UltraGridColumn("ObjectID").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraGridColumn3 AS Infragistics.Win.UltraWinGrid.UltraGridColumn NO-UNDO.
    ultraGridColumn3 = NEW Infragistics.Win.UltraWinGrid.UltraGridColumn("ObjectName").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraGridColumn4 AS Infragistics.Win.UltraWinGrid.UltraGridColumn NO-UNDO.
    ultraGridColumn4 = NEW Infragistics.Win.UltraWinGrid.UltraGridColumn("InstantiatingProcedure").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance2 AS Infragistics.Win.Appearance NO-UNDO.
    appearance2 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance3 AS Infragistics.Win.Appearance NO-UNDO.
    appearance3 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance4 AS Infragistics.Win.Appearance NO-UNDO.
    appearance4 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance5 AS Infragistics.Win.Appearance NO-UNDO.
    appearance5 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance6 AS Infragistics.Win.Appearance NO-UNDO.
    appearance6 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance7 AS Infragistics.Win.Appearance NO-UNDO.
    appearance7 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance8 AS Infragistics.Win.Appearance NO-UNDO.
    appearance8 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance9 AS Infragistics.Win.Appearance NO-UNDO.
    appearance9 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance10 AS Infragistics.Win.Appearance NO-UNDO.
    appearance10 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance11 AS Infragistics.Win.Appearance NO-UNDO.
    appearance11 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE appearance12 AS Infragistics.Win.Appearance NO-UNDO.
    appearance12 = NEW Infragistics.Win.Appearance().
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool8 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool8 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Refresh").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool9 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool9 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Send To Excel").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE ultraToolbar1 AS Infragistics.Win.UltraWinToolbars.UltraToolbar NO-UNDO.
    ultraToolbar1 = NEW Infragistics.Win.UltraWinToolbars.UltraToolbar("UltraToolbar1").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool10 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool10 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Refresh").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool11 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool11 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Send To Excel").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE textBoxTool1 AS Infragistics.Win.UltraWinToolbars.TextBoxTool NO-UNDO.
    textBoxTool1 = NEW Infragistics.Win.UltraWinToolbars.TextBoxTool("Num Objects").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool2 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool2 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Send To Excel").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE buttonTool4 AS Infragistics.Win.UltraWinToolbars.ButtonTool NO-UNDO.
    buttonTool4 = NEW Infragistics.Win.UltraWinToolbars.ButtonTool("Refresh").
    @VisualDesigner.FormMember (NeedsInitialize="true").
    DEFINE VARIABLE textBoxTool2 AS Infragistics.Win.UltraWinToolbars.TextBoxTool NO-UNDO.
    textBoxTool2 = NEW Infragistics.Win.UltraWinToolbars.TextBoxTool("Num Objects").
    THIS-OBJECT:ultraGrid1 = NEW Infragistics.Win.UltraWinGrid.UltraGrid().
    THIS-OBJECT:ultraToolbarsManager1 = NEW Infragistics.Win.UltraWinToolbars.UltraToolbarsManager(THIS-OBJECT:components).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left = NEW Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea().
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right = NEW Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea().
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top = NEW Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea().
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom = NEW Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea().
    THIS-OBJECT:ultraGridExcelExporter1 = NEW Infragistics.Win.UltraWinGrid.ExcelExport.UltraGridExcelExporter(THIS-OBJECT:components).
    CAST(THIS-OBJECT:ultraGrid1, System.ComponentModel.ISupportInitialize):BeginInit().
    CAST(THIS-OBJECT:ultraToolbarsManager1, System.ComponentModel.ISupportInitialize):BeginInit().
    THIS-OBJECT:SuspendLayout().
    /*  */
    /* ultraGrid1 */
    /*  */
    THIS-OBJECT:ultraToolbarsManager1:SetContextMenuUltra(THIS-OBJECT:ultraGrid1, "PopupMenuToolGrid").
    appearance1:BackColor = System.Drawing.SystemColors:Window.
    appearance1:BorderColor = System.Drawing.SystemColors:InactiveCaption.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Appearance = appearance1.
    THIS-OBJECT:ultraGrid1:DisplayLayout:AutoFitStyle = Infragistics.Win.UltraWinGrid.AutoFitStyle:ResizeAllColumns.
    ultraGridColumn1:Header:VisiblePosition = 0.
    ultraGridColumn1:RowLayoutColumnInfo:OriginX = 0.
    ultraGridColumn1:RowLayoutColumnInfo:OriginY = 0.
    ultraGridColumn1:RowLayoutColumnInfo:PreferredCellSize = NEW System.Drawing.Size(115, 0).
    ultraGridColumn1:RowLayoutColumnInfo:SpanX = 1.
    ultraGridColumn1:RowLayoutColumnInfo:SpanY = 2.
    ultraGridColumn1:Width = 210.
    ultraGridColumn2:Header:VisiblePosition = 1.
    ultraGridColumn2:RowLayoutColumnInfo:OriginX = 1.
    ultraGridColumn2:RowLayoutColumnInfo:OriginY = 0.
    ultraGridColumn2:RowLayoutColumnInfo:PreferredCellSize = NEW System.Drawing.Size(108, 0).
    ultraGridColumn2:RowLayoutColumnInfo:SpanX = 1.
    ultraGridColumn2:RowLayoutColumnInfo:SpanY = 2.
    ultraGridColumn2:Width = 233.
    ultraGridColumn3:Header:VisiblePosition = 2.
    ultraGridColumn3:RowLayoutColumnInfo:OriginX = 2.
    ultraGridColumn3:RowLayoutColumnInfo:OriginY = 0.
    ultraGridColumn3:RowLayoutColumnInfo:PreferredCellSize = NEW System.Drawing.Size(265, 0).
    ultraGridColumn3:RowLayoutColumnInfo:SpanX = 1.
    ultraGridColumn3:RowLayoutColumnInfo:SpanY = 2.
    ultraGridColumn3:Width = 233.
    ultraGridColumn4:Header:VisiblePosition = 3.
    ultraGridColumn4:RowLayoutColumnInfo:OriginX = 3.
    ultraGridColumn4:RowLayoutColumnInfo:OriginY = 0.
    ultraGridColumn4:RowLayoutColumnInfo:SpanX = 2.
    ultraGridColumn4:RowLayoutColumnInfo:SpanY = 2.
    @VisualDesigner.FormMember (NeedsInitialize="false", InitializeArray="true").
    DEFINE VARIABLE arrayvar0 AS System.Object EXTENT 4 NO-UNDO.
    arrayvar0[1] = ultraGridColumn1.
    arrayvar0[2] = ultraGridColumn2.
    arrayvar0[3] = ultraGridColumn3.
    arrayvar0[4] = ultraGridColumn4.
    ultraGridBand1:Columns:AddRange(arrayvar0).
    ultraGridBand1:UseRowLayout = TRUE.
    THIS-OBJECT:ultraGrid1:DisplayLayout:BandsSerializer:Add(ultraGridBand1).
    THIS-OBJECT:ultraGrid1:DisplayLayout:BorderStyle = Infragistics.Win.UIElementBorderStyle:Solid.
    THIS-OBJECT:ultraGrid1:DisplayLayout:CaptionVisible = Infragistics.Win.DefaultableBoolean:False.
    appearance2:BackColor = System.Drawing.SystemColors:ActiveBorder.
    appearance2:BackColor2 = System.Drawing.SystemColors:ControlDark.
    appearance2:BackGradientStyle = Infragistics.Win.GradientStyle:Vertical.
    appearance2:BorderColor = System.Drawing.SystemColors:Window.
    THIS-OBJECT:ultraGrid1:DisplayLayout:GroupByBox:Appearance = appearance2.
    appearance3:ForeColor = System.Drawing.SystemColors:GrayText.
    THIS-OBJECT:ultraGrid1:DisplayLayout:GroupByBox:BandLabelAppearance = appearance3.
    THIS-OBJECT:ultraGrid1:DisplayLayout:GroupByBox:BorderStyle = Infragistics.Win.UIElementBorderStyle:Solid.
    appearance4:BackColor = System.Drawing.SystemColors:ControlLightLight.
    appearance4:BackColor2 = System.Drawing.SystemColors:Control.
    appearance4:BackGradientStyle = Infragistics.Win.GradientStyle:Horizontal.
    appearance4:ForeColor = System.Drawing.SystemColors:GrayText.
    THIS-OBJECT:ultraGrid1:DisplayLayout:GroupByBox:PromptAppearance = appearance4.
    THIS-OBJECT:ultraGrid1:DisplayLayout:MaxColScrollRegions = 1.
    THIS-OBJECT:ultraGrid1:DisplayLayout:MaxRowScrollRegions = 1.
    appearance5:BackColor = System.Drawing.SystemColors:Window.
    appearance5:ForeColor = System.Drawing.SystemColors:ControlText.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:ActiveCellAppearance = appearance5.
    appearance6:BackColor = System.Drawing.SystemColors:Highlight.
    appearance6:ForeColor = System.Drawing.SystemColors:HighlightText.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:ActiveRowAppearance = appearance6.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:AllowAddNew = Infragistics.Win.UltraWinGrid.AllowAddNew:No.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:AllowDelete = Infragistics.Win.DefaultableBoolean:False.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:AllowRowFiltering = Infragistics.Win.DefaultableBoolean:False.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:AllowRowSummaries = Infragistics.Win.UltraWinGrid.AllowRowSummaries:False.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:AllowUpdate = Infragistics.Win.DefaultableBoolean:False.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:BorderStyleCell = Infragistics.Win.UIElementBorderStyle:Dotted.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:BorderStyleRow = Infragistics.Win.UIElementBorderStyle:Dotted.
    appearance7:BackColor = System.Drawing.SystemColors:Window.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:CardAreaAppearance = appearance7.
    appearance8:BorderColor = System.Drawing.Color:Silver.
    appearance8:TextTrimming = Infragistics.Win.TextTrimming:EllipsisCharacter.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:CellAppearance = appearance8.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:CellClickAction = Infragistics.Win.UltraWinGrid.CellClickAction:EditAndSelectText.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:CellPadding = 0.
    appearance9:BackColor = System.Drawing.SystemColors:Control.
    appearance9:BackColor2 = System.Drawing.SystemColors:ControlDark.
    appearance9:BackGradientAlignment = Infragistics.Win.GradientAlignment:Element.
    appearance9:BackGradientStyle = Infragistics.Win.GradientStyle:Horizontal.
    appearance9:BorderColor = System.Drawing.SystemColors:Window.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:GroupByRowAppearance = appearance9.
    appearance10:TextHAlignAsString = "Left".
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:HeaderAppearance = appearance10.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction:SortMulti.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:HeaderStyle = Infragistics.Win.HeaderStyle:WindowsXPCommand.
    appearance11:BackColor = System.Drawing.SystemColors:Window.
    appearance11:BorderColor = System.Drawing.Color:Silver.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:RowAppearance = appearance11.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:RowSelectors = Infragistics.Win.DefaultableBoolean:False.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:SelectTypeCell = Infragistics.Win.UltraWinGrid.SelectType:None.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:SelectTypeCol = Infragistics.Win.UltraWinGrid.SelectType:None.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:SelectTypeRow = Infragistics.Win.UltraWinGrid.SelectType:Single.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:SummaryDisplayArea = Infragistics.Win.UltraWinGrid.SummaryDisplayAreas:None.
    appearance12:BackColor = System.Drawing.SystemColors:ControlLight.
    THIS-OBJECT:ultraGrid1:DisplayLayout:Override:TemplateAddRowAppearance = appearance12.
    THIS-OBJECT:ultraGrid1:DisplayLayout:ScrollBounds = Infragistics.Win.UltraWinGrid.ScrollBounds:ScrollToFill.
    THIS-OBJECT:ultraGrid1:DisplayLayout:ScrollStyle = Infragistics.Win.UltraWinGrid.ScrollStyle:Immediate.
    THIS-OBJECT:ultraGrid1:Dock = System.Windows.Forms.DockStyle:Fill.
    THIS-OBJECT:ultraGrid1:Font = NEW System.Drawing.Font("Microsoft Sans Serif", 8.25, System.Drawing.FontStyle:Regular, System.Drawing.GraphicsUnit:Point, System.Convert:ToByte(0)).
    THIS-OBJECT:ultraGrid1:Location = NEW System.Drawing.Point(0, 48).
    THIS-OBJECT:ultraGrid1:Name = "ultraGrid1".
    THIS-OBJECT:ultraGrid1:Size = NEW System.Drawing.Size(852, 604).
    THIS-OBJECT:ultraGrid1:TabIndex = 0.
    THIS-OBJECT:ultraGrid1:Text = "ultraGrid1".
    THIS-OBJECT:ultraGrid1:KeyUp:SUBSCRIBE(THIS-OBJECT:ultraGrid1_KeyUp).
    /*  */
    /* ultraToolbarsManager1 */
    /*  */
    THIS-OBJECT:ultraToolbarsManager1:DesignerFlags = 1.
    THIS-OBJECT:ultraToolbarsManager1:DockWithinContainer = THIS-OBJECT.
    THIS-OBJECT:ultraToolbarsManager1:DockWithinContainerBaseType = Progress.Util.TypeHelper:GetType("pt.OERA.SILForm").
    @VisualDesigner.FormMember (NeedsInitialize="false", InitializeArray="true").
    DEFINE VARIABLE arrayvar1 AS Infragistics.Win.UltraWinToolbars.ToolBase EXTENT 2 NO-UNDO.
    arrayvar1[1] = buttonTool8.
    arrayvar1[2] = buttonTool9.
    THIS-OBJECT:ultraToolbarsManager1:MiniToolbar:NonInheritedTools:AddRange(arrayvar1).
    THIS-OBJECT:ultraToolbarsManager1:RuntimeCustomizationOptions = Infragistics.Win.UltraWinToolbars.RuntimeCustomizationOptions:None.
    THIS-OBJECT:ultraToolbarsManager1:ShowFullMenusDelay = 500.
    ultraToolbar1:DockedColumn = 0.
    ultraToolbar1:DockedRow = 0.
    @VisualDesigner.FormMember (NeedsInitialize="false", InitializeArray="true").
    DEFINE VARIABLE arrayvar2 AS Infragistics.Win.UltraWinToolbars.ToolBase EXTENT 3 NO-UNDO.
    arrayvar2[1] = buttonTool10.
    arrayvar2[2] = buttonTool11.
    arrayvar2[3] = textBoxTool1.
    ultraToolbar1:NonInheritedTools:AddRange(arrayvar2).
    ultraToolbar1:Text = "UltraToolbar1".
    @VisualDesigner.FormMember (NeedsInitialize="false", InitializeArray="true").
    DEFINE VARIABLE arrayvar3 AS Infragistics.Win.UltraWinToolbars.UltraToolbar EXTENT 1 NO-UNDO.
    arrayvar3[1] = ultraToolbar1.
    THIS-OBJECT:ultraToolbarsManager1:Toolbars:AddRange(arrayvar3).
    buttonTool2:SharedProps:Caption = "Send To E&xcel".
    buttonTool2:SharedProps:DisplayStyle = Infragistics.Win.UltraWinToolbars.ToolDisplayStyle:TextOnlyAlways.
    buttonTool2:SharedProps:Shortcut = System.Windows.Forms.Shortcut:CtrlShiftX.
    buttonTool2:SharedProps:ToolTipText = "CTRL-SHIFT-X".
    buttonTool4:SharedProps:Caption = "&Refresh".
    buttonTool4:SharedProps:DisplayStyle = Infragistics.Win.UltraWinToolbars.ToolDisplayStyle:TextOnlyAlways.
    buttonTool4:SharedProps:Shortcut = System.Windows.Forms.Shortcut:F5.
    buttonTool4:SharedProps:ToolTipText = "F5".
    textBoxTool2:SharedProps:Caption = "Num Objects:".
    textBoxTool2:SharedProps:DisplayStyle = Infragistics.Win.UltraWinToolbars.ToolDisplayStyle:TextOnlyAlways.
    @VisualDesigner.FormMember (NeedsInitialize="false", InitializeArray="true").
    DEFINE VARIABLE arrayvar4 AS Infragistics.Win.UltraWinToolbars.ToolBase EXTENT 3 NO-UNDO.
    arrayvar4[1] = buttonTool2.
    arrayvar4[2] = buttonTool4.
    arrayvar4[3] = textBoxTool2.
    THIS-OBJECT:ultraToolbarsManager1:Tools:AddRange(arrayvar4).
    THIS-OBJECT:ultraToolbarsManager1:ToolClick:SUBSCRIBE(THIS-OBJECT:ultraToolbarsManager1_ToolClick).
    /*  */
    /* m_ShowPersistentObjects_Toolbars_Dock_Area_Left */
    /*  */
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:AccessibleRole = System.Windows.Forms.AccessibleRole:Grouping.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:BackColor = System.Drawing.SystemColors:Control.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition:Left.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:ForeColor = System.Drawing.SystemColors:ControlText.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:Location = NEW System.Drawing.Point(0, 48).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:Name = "m_ShowPersistentObjects_Toolbars_Dock_Area_Left".
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:Size = NEW System.Drawing.Size(0, 604).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left:ToolbarsManager = THIS-OBJECT:ultraToolbarsManager1.
    /*  */
    /* m_ShowPersistentObjects_Toolbars_Dock_Area_Right */
    /*  */
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:AccessibleRole = System.Windows.Forms.AccessibleRole:Grouping.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:BackColor = System.Drawing.SystemColors:Control.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition:Right.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:ForeColor = System.Drawing.SystemColors:ControlText.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:Location = NEW System.Drawing.Point(852, 48).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:Name = "m_ShowPersistentObjects_Toolbars_Dock_Area_Right".
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:Size = NEW System.Drawing.Size(0, 604).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right:ToolbarsManager = THIS-OBJECT:ultraToolbarsManager1.
    /*  */
    /* m_ShowPersistentObjects_Toolbars_Dock_Area_Top */
    /*  */
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:AccessibleRole = System.Windows.Forms.AccessibleRole:Grouping.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:BackColor = System.Drawing.SystemColors:Control.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition:Top.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:ForeColor = System.Drawing.SystemColors:ControlText.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:Location = NEW System.Drawing.Point(0, 0).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:Name = "m_ShowPersistentObjects_Toolbars_Dock_Area_Top".
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:Size = NEW System.Drawing.Size(852, 48).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top:ToolbarsManager = THIS-OBJECT:ultraToolbarsManager1.
    /*  */
    /* m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom */
    /*  */
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:AccessibleRole = System.Windows.Forms.AccessibleRole:Grouping.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:BackColor = System.Drawing.SystemColors:Control.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition:Bottom.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:ForeColor = System.Drawing.SystemColors:ControlText.
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:Location = NEW System.Drawing.Point(0, 652).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:Name = "m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom".
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:Size = NEW System.Drawing.Size(852, 0).
    THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom:ToolbarsManager = THIS-OBJECT:ultraToolbarsManager1.
    /*  */
    /* ShowPersistentObjects */
    /*  */
    THIS-OBJECT:ClientSize = NEW System.Drawing.Size(852, 652).
    THIS-OBJECT:Controls:Add(THIS-OBJECT:ultraGrid1).
    THIS-OBJECT:Controls:Add(THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Left).
    THIS-OBJECT:Controls:Add(THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Right).
    THIS-OBJECT:Controls:Add(THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Top).
    THIS-OBJECT:Controls:Add(THIS-OBJECT:m_ShowPersistentObjects_Toolbars_Dock_Area_Bottom).
    THIS-OBJECT:Name = "ShowPersistentObjects".
    THIS-OBJECT:Text = "Persistent Objects - F5 or Activate to Refresh".
    THIS-OBJECT:Activated:SUBSCRIBE(THIS-OBJECT:ShowPersistentObjects_Activated).
    THIS-OBJECT:FormClosed:SUBSCRIBE(THIS-OBJECT:ShowPersistentObjects_FormClosed).
    THIS-OBJECT:FormClosing:SUBSCRIBE(THIS-OBJECT:ShowPersistentObjects_FormClosing).
    CAST(THIS-OBJECT:ultraGrid1, System.ComponentModel.ISupportInitialize):EndInit().
    CAST(THIS-OBJECT:ultraToolbarsManager1, System.ComponentModel.ISupportInitialize):EndInit().
    THIS-OBJECT:ResumeLayout(FALSE).
    CATCH e AS Progress.Lang.Error:
      UNDO, THROW e.
    END CATCH.
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/
@VisualDesigner.
  METHOD PRIVATE VOID ShowPersistentObjects_Activated( INPUT sender AS System.Object, INPUT e AS System.EventArgs ):
    /* we'll refresh the content every time the window is activated */
    THIS-OBJECT:FillPersistentObjects().
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

@VisualDesigner.
  METHOD PRIVATE VOID ShowPersistentObjects_FormClosed( INPUT sender AS System.Object, INPUT e AS System.Windows.Forms.FormClosedEventArgs ):
    /* from documentation: Progress Software Corporation recommends calling the Dispose( ) method before you delete
       or release the ProBindingSource instance for garbage collection, especially for
       ProBindingSource instances bound to ProDataSets, which can use a lot of memory. */
    IF VALID-OBJECT(THIS-OBJECT:objProBindingSource)
    THEN DO:
      THIS-OBJECT:objProBindingSource:Dispose().
      DELETE OBJECT THIS-OBJECT:objProBindingSource NO-ERROR.
    END. /* IF VALID-OBJECT(objProBindingSource) */
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

@VisualDesigner.
  METHOD PRIVATE VOID ShowPersistentObjects_FormClosing( INPUT sender AS System.Object, INPUT e AS System.Windows.Forms.FormClosingEventArgs ):
/*    IF VALID-OBJECT(THIS-OBJECT:ultraGrid1:ActiveRow) AND THIS-OBJECT:ultraGrid1:ActiveRow:Selected AND NOT THIS-OBJECT:lCancelled*/
/*    THEN THIS-OBJECT:iSelectedLanguageNo = UNBOX(THIS-OBJECT:ultraGrid1:Selected:Rows[0]:Cells["Language-no"]:Value).           */

  END METHOD.


  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

@VisualDesigner.
  METHOD PRIVATE VOID ultraGrid1_KeyUp( INPUT sender AS System.Object, INPUT e AS System.Windows.Forms.KeyEventArgs ):
    IF e:KeyCode:Equals(System.Windows.Forms.Keys:Escape)
    THEN DO:
      e:Handled = TRUE.
      THIS-OBJECT:Close().
    END. /* IF e:KeyCode:Equals(System.Windows.Forms.Keys:Return) OR e:KeyCode:Equals(System.Windows.Forms.Keys:Escape) */
  END METHOD.

  /*------------------------------------------------------------------------------
      Purpose:                                      
      Notes:                                      
  ------------------------------------------------------------------------------*/

@VisualDesigner.
  METHOD PRIVATE VOID ultraToolbarsManager1_ToolClick( INPUT sender AS System.Object, INPUT e AS Infragistics.Win.UltraWinToolbars.ToolClickEventArgs ):
    DEFINE VARIABLE cToolKey AS CHARACTER NO-UNDO.
    DEFINE VARIABLE cCurrentDirectory AS CHARACTER NO-UNDO.
    DEFINE VARIABLE cExcelFileFullPathName AS CHARACTER NO-UNDO.
    
    cToolKey = e:Tool:Key.

    CASE cToolKey:
      WHEN "Refresh":U
      THEN THIS-OBJECT:FillPersistentObjects().
      WHEN "Send To Excel":U
      THEN DO:
        cExcelFileFullPathName = SUBSTITUTE("&1PersistentObjects&2.xls":U, SESSION:TEMP-DIRECTORY, REPLACE(REPLACE(ISO-DATE(DATETIME(DATE(NOW), MTIME(NOW))),":":U,"-":U),".":U,"-":U)).
        THIS-OBJECT:ultraGridExcelExporter1:Export(THIS-OBJECT:ultraGrid1, cExcelFileFullPathName).
        System.Diagnostics.Process:Start(cExcelFileFullPathName).
      END. /* WHEN "Send To Excel":U */
    END. /* CASE cToolKey: */
  END METHOD.

  DESTRUCTOR PUBLIC ShowPersistentObjects ( ):
 
    IF VALID-OBJECT(components) THEN DO:
      CAST(components, System.IDisposable):Dispose().
    END.
    
  END DESTRUCTOR.

END CLASS.